==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/core/lumina-info/i18n/lumina-info_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Lumina Desktop Information</source>
        <translation>Lumina-Arbeitsplatzinformation</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="60"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="89"/>
        <source>Source Repository</source>
        <translation>Quellarchiv</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Lumina Website</source>
        <translation>Lumina Website</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Bug Reports</source>
        <translation>Fehlerberichte</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="179"/>
        <source>Desktop Version:</source>
        <translation>Arbeitsplatzversion:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="202"/>
        <source>OS Build:</source>
        <translation>OS Build Version:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Qt Version:</source>
        <translation>Qt-Version:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="276"/>
        <source>Ask the Community</source>
        <translation>Fragen Sie die Community</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="233"/>
        <source>View Information</source>
        <translation>Informationen anzeigen</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="315"/>
        <source>Acknowledgements</source>
        <translation>Danksagungen</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="333"/>
        <source>Project Lead:</source>
        <translation>Projektleitung:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="340"/>
        <source>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="353"/>
        <source>Contributors:</source>
        <translation>Mitwirkende:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="366"/>
        <source>Sponsors:</source>
        <translation>Sponsoren:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="428"/>
        <source>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Open in web browser&lt;a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Im Web-Browser öffnen&lt;a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="454"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
</TS>

==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/core/lumina-info/i18n/lumina-info_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Lumina Desktop Information</source>
        <translation>Lumina-Arbeitsplatzinformation</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="60"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="89"/>
        <source>Source Repository</source>
        <translation>Quellarchiv</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Lumina Website</source>
        <translation>Lumina-Webseite</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Bug Reports</source>
        <translation>Fehlerberichte</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="179"/>
        <source>Desktop Version:</source>
        <translation>Arbeitsplatzversion:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="202"/>
        <source>OS Build:</source>
        <translation>OS Build Version:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Qt Version:</source>
        <translation>Qt-Version:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="276"/>
        <source>Ask the Community</source>
        <translation>Fragen Sie die Community</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="233"/>
        <source>View Information</source>
        <translation>Informationen anzeigen</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="315"/>
        <source>Acknowledgements</source>
        <translation>Danksagungen</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="333"/>
        <source>Project Lead:</source>
        <translation>Projektleitung:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="340"/>
        <source>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="353"/>
        <source>Contributors:</source>
        <translation>Mitwirkende:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="366"/>
        <source>Sponsors:</source>
        <translation>Sponsoren:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="428"/>
        <source>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Open in web browser&lt;a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Im Web-Browser öffnen&lt;a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="454"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
</TS>
